pilas.tareas.Tareas

Package pilas :: Module tareas :: Class Tareas |
[hide private]
[frames] | no frames]

# Class Tareas

source code

    object --+
             |
            Tareas

Contenedor de tareas a ejecutar por tiempo.

El Tareas es un planificador de tareas, permite que podamos ejecutar funciones y métodos luego de transcurrido el tiempo que queramos.

Por ejemplo, si se quiere que el planificardor ejecute una función dentro de dos segundos podemos escribir:

    >>> pilas.mundo.agregar_tarea(2, hola)

o bien, especificando argumentos para esa función:

    >>> pilas.mundo.agregar_tarea(4, hola, 'persona')

La función que se especifique como segundo argumento tiene que retornar True o False. Si retorna True será colocada nuevamente en la cola de tareas una vez que se ejecute (esto es útil para crear bucles).

Instance Methods | [hide private]
__init__(self) Inicializa el gestor de tareas. | source code
obtener_cantidad_de_tareas_planificadas(self) Retora la cantidad de tareas planificadas. | source code
actualizar(self, dt) Actualiza los contadores de tiempo y ejecuta las tareas pendientes. | source code
_agregar(self, tarea) Agrega una nueva tarea para ejecutarse luego. | source code
una_vez(self, time_out, function, params=`[``]`) Genera una tarea que se ejecutará usan sola vez. | source code
siempre(self, time_out, function, params=`[``]`) Genera una tarea para ejecutar todo el tiempo, sin expiración. | source code
condicional(self, time_out, function, params=`[``]`) Genera una tarea que se puede ejecutar una vez o mas, pero que tiene una condición. | source code
eliminar_tarea(self, tarea) Elimina una tarea de la lista de tareas planificadas. | source code
eliminar_todas(self) Elimina todas las tareas de la lista de planificadas. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Inicializa el gestor de tareas. Overrides: object.__init__

### actualizar(self, dt) | source code
Actualiza los contadores de tiempo y ejecuta las tareas pendientes. :param dt: Tiempo transcurrido desde la anterior llamada.

### _agregar(self, tarea) | source code
Agrega una nueva tarea para ejecutarse luego. :param tarea: Referencia a la tarea que se debe agregar.

### una_vez(self, time_out, function, params=`[``]`) | source code
Genera una tarea que se ejecutará usan sola vez. :param time_out: Cantidad se segundos que deben transcurrir para ejecutar la tarea. :param function: Función a ejecutar para lanzar la tarea. :param params: Parámetros que tiene que recibir la función a ejecutar.

### siempre(self, time_out, function, params=`[``]`) | source code
Genera una tarea para ejecutar todo el tiempo, sin expiración. :param time_out: Cantidad se segundos que deben transcurrir para ejecutar la tarea. :param function: Función a ejecutar para lanzar la tarea. :param params: Parámetros que tiene que recibir la función a ejecutar.

### condicional(self, time_out, function, params=`[``]`) | source code
Genera una tarea que se puede ejecutar una vez o mas, pero que tiene una condición. La tarea se ejecutará hasta que la función a ejecutar revuelva False. :param time_out: Cantidad se segundos que deben transcurrir para ejecutar la tarea. :param function: Función a ejecutar para lanzar la tarea. :param params: Parámetros que tiene que recibir la función a ejecutar.

### eliminar_tarea(self, tarea) | source code
Elimina una tarea de la lista de tareas planificadas. :param tarea: Referencia a la tarea que se tiene que eliminar.